receiver_category — EuRepoC 0.1.2 documentation

# receiver_category

The receiver category refers to the sectors targeted by the cyber incident.

The following receiver categories can be queried in the database, use the category’s full name, as spelt below. Leaving the filter to its default value (None) will return all receiver categories.

- Corporate Targets (corporate targets only coded if the respective company is not part of the critical infrastructure definition)

- Critical infrastructure

- Education

- End user(s) / specially protected groups

- International / supranational organization

- Media

- Other

- Science

- Social groups

- State institutions / political system

- Unknown